<?php
/**
 * @version     1.0.1
 * @package     com_seopanel
 * @copyright   Copyright (C) 2011. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Created by Jennifer Grotheer - http://www.seo-panel.de
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Seopanel records.
 */
class SeopanelModelKeyDetail extends JModellist
{

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array())
    {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                                'id', 'a.id',
                'ordering', 's.ordering',
                'state', 's.state',
                'name', 's.name',
                'lang_code', 's.lang_code',
                'country_code', 's.country_code',
                'website_id', 's.website_id',
                'searchengines', 's.searchengines',
                'keyword_id', 's.keyword_id',
                'url', 'sd.url',
            );
        }

        parent::__construct($config);
    }


	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $app->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$published = $app->getUserStateFromRequest($this->context.'.filter.state', 'filter_published', '', 'string');
		$this->setState('filter.state', $published);

		$keyword_id = $app->getUserStateFromRequest($this->context.'.filter.keyword_id', 'filter_keyword', '', 'string');
		$this->setState('filter.keyword_id', $keyword_id);

		$website_id = $app->getUserStateFromRequest($this->context.'.filter.website_id', 'filter_website', '', 'string');
		$this->setState('filter.website_id', $website_id);

		$searchengine_id = $app->getUserStateFromRequest($this->context.'.filter.searchengine_id', 'filter_searchengine', '', 'string');
		$this->setState('filter.searchengine_id', $searchengine_id);
		
		$searchdate_time = $app->getUserStateFromRequest($this->context.'.filter.searchdate_time', 'filter_searchdate', '', 'string');
		$this->setState('filter.searchdate_time', $searchdate_time);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_seopanel');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('s.rank', 'desc');
	}

	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param	string		$id	A prefix for the store id.
	 * @return	string		A store id.
	 * @since	1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id.= ':' . $this->getState('filter.search');
		$id.= ':' . $this->getState('filter.state');
		$id.= ':' . $this->getState('filter.keyword_id');
		$id.= ':' . $this->getState('filter.searchengine_id');
		$id.= ':' . $this->getState('filter.searchdate_time');
		$id.= ':' . $this->getState('filter.website_id');
		return parent::getStoreId($id);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);

		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select',
				's.*' /// this is es 
				
			)
		);
		
		$query->from('`#__seopanel_searchresults` AS s, `#__seopanel_searchresultdetails` AS sd, `#__seopanel_keywords` AS k ');

                $query->select('sd.*'); 
                $query->select('k.*'); 
                $query->where('s.id = sd.searchresult_id');
                $query->where('k.id =  s.keyword_id');
                $query->group('sd.url');
                
                $query->select('lang.lang_name');
                $query->select('country.country_name');                
                $query->join('LEFT', '#__seopanel_languages AS lang ON k.lang_code=lang.lang_code');
                $query->join('LEFT', '#__seopanel_country AS country ON k.country_code=country.country_code');

    $searchdatefilter = $this->getState('filter.searchdate_time');
    if (!empty($searchdatefilter)) { 

    $query->where('time = '.$searchdatefilter);
    } else {
    $query->where('time ='.time());  
   
    }



    $searchenginefilter = $this->getState('filter.searchengine_id');
    if (!empty($searchenginefilter)) { 
    $query->where('s.searchengine_id='.$searchenginefilter);
   
    } else {
    $query->where('s.searchengine_id=1');         
    }


    $keywordfilter = $this->getState('filter.keyword_id');
    if (!empty($keywordfilter)) { 
    $query->where('s.keyword_id='.$keywordfilter);
    $query->order('s.rank');
    
    } else {
    $query->order('s.rank');
    }

    $websitefilter = $this->getState('filter.website_id');
    if (!empty($websitefilter)) { 
    $query->where('k.website_id='.$websitefilter);
    $query->order('s.rank');
    
    }


		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('sd.searchresult_id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->getEscaped($search, true).'%');
                $query->where('( sd.description LIKE '.$search.' OR sd.title LIKE '.$search.' OR sd.url LIKE '.$search.' )');
			}
		}

		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
		    $query->order($db->getEscaped($orderCol.' '.$orderDirn));
        }

    //echo nl2br(str_replace('#__','jom_',$query));
		return $query;
	}
}


