<?php
/**
 * @version     1.0.1
 * @package     com_seopanel
 * @copyright   Copyright (C) 2011. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      Created by Jennifer Grotheer - http://www.seo-panel.de
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Seopanel records.
 */
class SeopanelModelVisibility extends JModelList
{

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array())
    {
        parent::__construct($config);
    }

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $app->getUserStateFromRequest($this->context.'.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$searchdate_time = $app->getUserStateFromRequest($this->context.'.filter.searchdate_time', 'filter_searchdate', '', 'string');
		$this->setState('filter.searchdate_time', $searchdate_time);

		$website_id = $app->getUserStateFromRequest($this->context.'.filter.website_id', 'filter_website', '', 'string');
		$this->setState('filter.website_id', $website_id);

		// Load the parameters.
		$params = JComponentHelper::getParams('com_seopanel');
		$this->setState('params', $params);

		// List state information.
		parent::populateState();
	}

	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param	string		$id	A prefix for the store id.
	 * @return	string		A store id.
	 * @since	1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id.= ':' . $this->getState('filter.search');
		$id.= ':' . $this->getState('filter.searchdate_time');
		$id.= ':' . $this->getState('filter.keyword_id');
		return parent::getStoreId($id);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return	JDatabaseQuery
	 * @since	1.6
	 */
	protected function getListQuery()
	{
		// Create a new query object.
		$db		= $this->getDbo();
		$query	= $db->getQuery(true);


    // Join over the users for the checked out user.

    if ($this->getState('filter.website_id')) {

    $searchdatefilter = $this->getState('filter.searchdate_time');
    $websitefilter = $this->getState('filter.website_id');
    

    
                $query->select('*');
		            $query->from('#__seopanel_saturationresults AS b');
                $query->where('b.website_id='.$websitefilter);
                $query->where('b.result_time <='.$searchdatefilter);
                $query->order('b.result_time desc');
 
 
 
            } else {

		// Select the required fields from the table.
    $query->select('*');
		$query->from('`#__seopanel_websites` AS a');
                    
}

		// Filter by search in title
		$search = $this->getState('filter.search');
		if (!empty($search)) {
			if (stripos($search, 'id:') === 0) {
				$query->where('a.id = '.(int) substr($search, 3));
			} else {
				$search = $db->Quote('%'.$db->getEscaped($search, true).'%');
                $query->where('( a.domain LIKE '.$search.' )');
			}
		}


		// Add the list ordering clause.
		$orderCol	= $this->state->get('list.ordering');
		$orderDirn	= $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
		    $query->order($db->getEscaped($orderCol.' '.$orderDirn));
        }

		return $query;
	}
}
